@@ -157,11 +157,7 @@ impl SmartEngine {
             .imports()
             .next()
             .ok_or_else(|| Error::msg("At least one import is required"))?;
-        linker.func_wrap(
-            host_fn_import.module(),
-            host_fn_import.name().unwrap_or(""),
-            host_fn,
-        )?;
+        linker.func_wrap(host_fn_import.module(), host_fn_import.name(), host_fn)?;
         linker.instantiate(store, module)
     }
 }
@@ -313,7 +309,7 @@ impl dyn SmartModuleInstance + '_ {
         join_last_record: Option<&Record>,
     ) -> Result<(Batch, Option<SmartModuleRuntimeError>), Error> {
         let mut smartmodule_batch = Batch::<MemoryRecords>::default();
-        smartmodule_batch.base_offset = -1; // indicate this is unitialized
+        smartmodule_batch.base_offset = -1; // indicate this is uninitialized
         smartmodule_batch.set_offset_delta(-1); // make add_to_offset_delta correctly
 
         let mut total_bytes = 0;
